!> \file bilan_eau.f90
!! Clacul du bilan d'eau sur la calotte
!<
      

!> SUBROUTINE: bilan_eau
!! Calcule le bilan d'eau sur la grille GRISLI 
!! \author C. Dumas
!! \date 20/02/2017
!! @note Permet de vérifier que le bilan d'eau est ok et qu'il n'y a pas de fuite.
!>

! bilan d'eau :
! ce qui tombe : Acc
! ce qui sort : Bmelt, Abl, calving, ablbord
! ce qui est stocké : masse de glace
! le total de tous ces termes doit être constant (sur la grille, pas localement)

subroutine bilan_eau


use module3D_phy
implicit none

real :: sum_H

real,dimension(nx,ny) :: bm_dt,bmelt_dt

tot_water(:,:)=0.

bm_dt(:,:)=0.
bmelt_dt(:,:)=0.

bm_dt(2:nx-1,2:ny-1)=bm(2:nx-1,2:ny-1)*dt
bmelt_dt(2:nx-1,2:ny-1)=bmelt(2:nx-1,2:ny-1)*dt
!~ where (Bm(:,:).lt.0.)
!~ 	bm_dt(:,:)=max(Bm(:,:)*dt,-H(:,:))
!~ elsewhere
!~ 	bm_dt(:,:)=bm(:,:)*dt
!~ endwhere

!~ where (Bmelt(:,:).lt.0.)
!~ 	bmelt_dt(:,:)=max(Bmelt(:,:)*dt,-H(:,:))
!~ elsewhere
!~ 	bmelt_dt(:,:)=bmelt(:,:)*dt
!~ endwhere


! on fait la somme sur la grille en excluant les bords :

sum_H = sum(H(2:nx-1,2:ny-1),mask=ice(2:nx-1,2:ny-1)==1)

if (nt.eq.1) then
  diff_H=0.
else
  diff_H = diff_H + (sum_H - sum_H_old) ! on calcul la variation de volume a chaque dt
endif

diff_H_2D(2:nx-1,2:ny-1)=H(2:nx-1,2:ny-1)-H_beau_old(2:nx-1,2:ny-1)

where (ice(2:nx-1,2:ny-1).eq.1)
	Bm_dtt(2:nx-1,2:ny-1) = Bm_dtt(2:nx-1,2:ny-1) + Bm_dt(2:nx-1,2:ny-1) !* dt ! somme Bm sur dt
	bmelt_dtt(2:nx-1,2:ny-1) = bmelt_dtt(2:nx-1,2:ny-1) + bmelt_dt(2:nx-1,2:ny-1) ! * dt ! somme bmelt sur dt
endwhere

if (isynchro.eq.1) then
! on raisonne en bilan annuel pour simplifier :
!~ 	where (ice(2:nx-1,2:ny-1).eq.1)
!~ 		tot_water(2:nx-1,2:ny-1) = (Bm_dtt(2:nx-1,2:ny-1) - Bmelt_dtt(2:nx-1,2:ny-1) + calv_dtt(2:nx-1,2:ny-1) - ablbord_dtt(2:nx-1,2:ny-1)) / dtt 
!~ 		elsewhere
!~ 		tot_water(2:nx-1,2:ny-1) = (calv_dtt(2:nx-1,2:ny-1) - ablbord_dtt(2:nx-1,2:ny-1)) / dtt
!~ 	endwhere
!cdc pas besoin du test sur ice ici, il a ete fait avant (et le masque ice varie a chaque dt)	
  tot_water(2:nx-1,2:ny-1) = (Bm_dtt(2:nx-1,2:ny-1) - Bmelt_dtt(2:nx-1,2:ny-1) + calv_dtt(2:nx-1,2:ny-1) - ablbord_dtt(2:nx-1,2:ny-1)) / dtt
   
! bilan d'eau sur la grille :
	water_bilan=sum(tot_water(:,:))
	diff_H = diff_H/dtt

!999 format(f0.2,1x,e15.8,1x,i10,8(1x,e15.8))
!	write(6,999),time,sum_H,count(ice(:,:)==1),diff_H,water_bilan,sum(calv_dtt(:,:))/dtt,sum(ablbord_dtt(:,:))/dtt,sum(bmelt_dtt(:,:),mask=ice(:,:)==1)/dtt,sum(bm(:,:),mask=ice(:,:)==1),sum(Bm_dtt(:,:))/dtt,sum(bmelt_dtt(:,:))/dtt
	diff_H_water_bilan(2:nx-1,2:ny-1)=tot_water(2:nx-1,2:ny-1)-diff_H_2D(2:nx-1,2:ny-1)

endif
sum_H_old=sum_H

H_beau_old(:,:)=H(:,:)

end subroutine bilan_eau
